summaryrefslogtreecommitdiffstats
path: root/kftpgrabber/src/widgets/browser/treeview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kftpgrabber/src/widgets/browser/treeview.h')
-rw-r--r--kftpgrabber/src/widgets/browser/treeview.h48
1 files changed, 24 insertions, 24 deletions
diff --git a/kftpgrabber/src/widgets/browser/treeview.h b/kftpgrabber/src/widgets/browser/treeview.h
index 220ac88..d325fe6 100644
--- a/kftpgrabber/src/widgets/browser/treeview.h
+++ b/kftpgrabber/src/widgets/browser/treeview.h
@@ -36,12 +36,12 @@
#ifndef KFTPFILEDIRTREEVIEW_H
#define KFTPFILEDIRTREEVIEW_H
-#include <klistview.h>
-#include <klocale.h>
+#include <tdelistview.h>
+#include <tdelocale.h>
#include <kurl.h>
-#include <qpixmap.h>
-#include <qdict.h>
+#include <ntqpixmap.h>
+#include <ntqdict.h>
namespace KFTPWidgets {
@@ -55,7 +55,7 @@ class TreeViewItem;
*
* @author Jernej Kos
*/
-class TreeView : public KListView
+class TreeView : public TDEListView
{
Q_OBJECT
friend class ListView;
@@ -66,7 +66,7 @@ public:
*
* @param parent The parent widget
*/
- TreeView(QWidget *parent);
+ TreeView(TQWidget *parent);
/**
* Class destructor.
@@ -78,7 +78,7 @@ public:
*
* @param url The url to open
*/
- int openUrl(const KURL &url, QListViewItem *parent = 0);
+ int openUrl(const KURL &url, TQListViewItem *parent = 0);
/**
* Remove the folder's child items.
@@ -101,7 +101,7 @@ public:
* @param url The folder's URL
* @param icon The icon to use
*/
- void createFolder(const KURL &url, QPixmap icon);
+ void createFolder(const KURL &url, TQPixmap icon);
/**
* Clear all items in the view and create a new root item.
@@ -117,25 +117,25 @@ public:
*/
void endUpdate(const KURL &url);
private:
- QDict<TreeViewItem> m_treeItems;
+ TQDict<TreeViewItem> m_treeItems;
bool m_noItemOpen;
/* Drag & drop support */
- QListViewItem *m_dropItem;
- QDragObject *m_dragObject;
+ TQListViewItem *m_dropItem;
+ TQDragObject *m_dragObject;
- QDragObject *dragObject();
+ TQDragObject *dragObject();
void startDrag();
- bool acceptDrag(QDropEvent *e);
- void contentsDragEnterEvent(QDragEnterEvent *e);
- void contentsDragMoveEvent(QDragMoveEvent *e);
- void contentsDragLeaveEvent(QDragLeaveEvent*);
- void contentsDropEvent(QDropEvent *e);
+ bool acceptDrag(TQDropEvent *e);
+ void contentsDragEnterEvent(TQDragEnterEvent *e);
+ void contentsDragMoveEvent(TQDragMoveEvent *e);
+ void contentsDragLeaveEvent(TQDragLeaveEvent*);
+ void contentsDropEvent(TQDropEvent *e);
protected:
- QListViewItem *findItem(QListViewItem *parent, const QString &name);
+ TQListViewItem *findItem(TQListViewItem *parent, const TQString &name);
private slots:
- void slotClicked(QListViewItem *item);
- void slotDoubleClicked(QListViewItem *item);
+ void slotClicked(TQListViewItem *item);
+ void slotDoubleClicked(TQListViewItem *item);
signals:
void pathChanged(const KURL &url);
};
@@ -145,7 +145,7 @@ signals:
*
* @author Jernej Kos
*/
-class TreeViewItem : public QListViewItem
+class TreeViewItem : public TQListViewItem
{
friend class TreeView;
public:
@@ -164,7 +164,7 @@ public:
* @param parent The parent list view item
* @param url This item's URL
*/
- TreeViewItem(TreeView *tree, QListViewItem *parent, const KURL &url);
+ TreeViewItem(TreeView *tree, TQListViewItem *parent, const KURL &url);
/**
* Class destructor.
@@ -173,9 +173,9 @@ public:
protected:
/**
* @overload
* Reimplemented from QListViewItem to provide proper comparation.
*/
- int compare(QListViewItem *i, int col, bool) const;
+ int compare(TQListViewItem *i, int col, bool) const;
private:
TreeView *m_tree;
KURL m_url;
@@ -173,9 +173,9 @@ public:
/**
* @overload
- * Reimplemented from QListViewItem to provide proper comparation.
+ * Reimplemented from TQListViewItem to provide proper comparation.
*/